@@ -852,7 +852,7 @@ launcher_dialog_item_button_clicked (GtkWidget            *button,
 
           /* ask the user */
           toplevel = gtk_widget_get_toplevel (button);
-          if (xfce_dialog_confirm (GTK_WINDOW (toplevel), "edit-delete", _("Remove"),
+          if (xfce_dialog_confirm (GTK_WINDOW (toplevel), "edit-delete", _("_Remove"),
                   _("If you delete an item, it will be permanently removed"),
                   _("Are you sure you want to remove \"%s\"?"),
                   panel_str_is_empty (display_name) ? _("Unnamed item") : display_name))
